@@ -1,7 +1,7 @@
 /*
 mailtextbody - a program that returns the body of an email message
 
-Copyright (C) 2005-2008 Toastfreeware <toast@toastfreeware.priv.at> - 
+Copyright (C) 2005-2012 Toastfreeware <toast@toastfreeware.priv.at> - 
 Philipp Spitzer and Gregor Herrmann
 
 This program is free software; you can redistribute it and/or modify
@@ -29,17 +29,16 @@ using namespace std;
 using namespace mimetic;
 
 
-const char *argp_program_version = "mailtextbody 0.1.2";
+const char *argp_program_version = "mailtextbody 0.1.3";
 const char *argp_program_bug_address = "<toast@toastfreeware.priv.at>";
 static char doc[] = "mailtextbody - a program that returns the body of an email message";
 static char args_doc[] = "mailtextbody < rawmail > textplain";
 static struct argp_option argp_options[] = {{0}};
-	
 
 
 // parse function for the program options
 static error_t parse_opt(int, char*, argp_state*) {
-	return ARGP_ERR_UNKNOWN;
+	return (error_t)ARGP_ERR_UNKNOWN;
 }
 
 
